@@ -199,6 +199,15 @@ AbstractGeom <- R6::R6Class(
           time_stamp = 0
         }
       }
+      is_na = is.na(value)
+      if(all(is_na)){
+        self$keyframes[[name]] = NULL
+        return(invisible())
+      }else{
+        value = value[!is_na]
+        time_stamp = time_stamp[!is_na]
+      }
+
 
       kf = KeyFrame$new(name = name, value = value, time = time_stamp,
                         dtype = ifelse( isTRUE(is.numeric(value)), 'continuous', 'discrete'),
